#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .temperature_types import Celsius, Fahrenheit

__author__ = 'Edson Pimenta and Dávilos Tavares'
__credits__ = ['Edson Pimenta', 'Dávilos Tavares']
__license__ = 'GPL-3.0'
__version__ = '0.3.0'
__maintainer__ = [
    'Edson Pimenta <edson.tibo@gmail.com>',
    'Dávilos Tavares <daviloscostagg@hotmail.com>',
]
__status__ = 'Development'
__all__ = ['Celsius', 'Fahrenheit']
